==> mieru_2.4.4.tar.gz: mieru-2.4.4/mieru/opt/mieru/gui/qml/i18n/qml_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>BitcoinButton</name>
    <message>
        <location filename="../BitcoinButton.qml" line="34"/>
        <source>Bitcoin address</source>
        <translation>Bitcoin Adresse</translation>
    </message>
    <message>
        <location filename="../BitcoinButton.qml" line="111"/>
        <source>Copy address</source>
        <translation>Adresse kopieren</translation>
    </message>
    <message>
        <location filename="../BitcoinButton.qml" line="116"/>
        <source>Bitcoin address copied to clipboard</source>
        <translation>Die Bitcoin Adresse wurde in Zwischenablage kopiert</translation>
    </message>
</context>
<context>
    <name>FileSelector</name>
    <message>
        <location filename="../FileSelector.qml" line="14"/>
        <source>File Selector</source>
        <translation>Datei auswählen</translation>
    </message>
</context>
<context>
    <name>FlattrButton</name>
    <message>
        <location filename="../FlattrButton.qml" line="25"/>
        <source>Opening &lt;b&gt;Flattr&lt;/b&gt; donation page, &lt;b&gt;thanks&lt;/b&gt;!</source>
        <translation>Die &lt;b&gt;Flattr&lt;/b&gt; Spendeseite wird geöffnet, &lt;b&gt;vielen dank&lt;/b&gt;!</translation>
    </message>
</context>
<context>
    <name>HistoryPage</name>
    <message>
        <location filename="../HistoryPage.qml" line="20"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="31"/>
        <location filename="../HistoryPage.qml" line="118"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="54"/>
        <source>Delete items</source>
        <translation>Einträge löschen</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="54"/>
        <source>Do not delete items</source>
        <translation>Keine Einträge löschen</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="57"/>
        <source>Select items to delete</source>
        <translation>Einträge zum Löschen auswählen</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="61"/>
        <location filename="../HistoryPage.qml" line="115"/>
        <source>Erase history</source>
        <translation>Verlauf löschen</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="74"/>
        <source>no entries</source>
        <translation>keine Einträge</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="116"/>
        <source>Do you want to erase the history of all mangas and comic books opened by Mieru?</source>
        <translation>Möchten Sie wirklich den gesamten Verlauf löschen?</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="117"/>
        <source>Erase</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>InfoPage</name>
    <message>
        <location filename="../InfoPage.qml" line="14"/>
        <source>Info</source>
        <translation>Informationen</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="18"/>
        <source>Stats</source>
        <translation>Statistik</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="22"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="77"/>
        <source>Properties</source>
        <translation>Eigenschaften</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="80"/>
        <source>Pages</source>
        <translation>Seiten</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="83"/>
        <source>Path</source>
        <translation>Pfad</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="91"/>
        <source>Online search</source>
        <translation>Online Suche</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="97"/>
        <source>Opening &lt;b&gt;Google&lt;/b&gt; search</source>
        <translation>Öffne &lt;b&gt;Google&lt;/b&gt; Suche</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="106"/>
        <source>Opening &lt;b&gt;Wikipedia&lt;/b&gt; search</source>
        <translation>Öffne &lt;b&gt;Wikipedia&lt;/b&gt; Suche</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="115"/>
        <source>Opening &lt;b&gt;Manga updates&lt;/b&gt; search</source>
        <translation>Öffne &lt;b&gt;Manga Updates&lt;/b&gt; Suche</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="132"/>
        <source>Usage Statistics</source>
        <translation>Nutzungsstatistiken</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="162"/>
        <location filename="../InfoPage.qml" line="268"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="207"/>
        <source>Mieru is a flexible Manga and comic book reader.</source>
        <translation>Mieru ist ein flexibles Manga und Comic Anzeigeprogramm.</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="243"/>
        <source>main developer</source>
        <translation>Entwickler</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="246"/>
        <source>email</source>
        <translation>e-Mail</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="250"/>
        <source>www</source>
        <translation>Web</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="255"/>
        <source>discussion</source>
        <translation>Diskussion</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation type="obsolete">Spenden</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="266"/>
        <source>Reset all usage statistics</source>
        <translation>Nutzungsstatistiken zurücksetzen</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="267"/>
        <source>Do you really want to reset all usage statistics?</source>
        <translation>Möchten Sie wirklich alle Nutzungsstatistiken rücksetzen?</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="269"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../MainView.qml" line="156"/>
        <source>original</source>
        <translation>Original</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="158"/>
        <source>width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="160"/>
        <source>height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="162"/>
        <source>screen</source>
        <translation>Bildschirm</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="164"/>
        <source>orient</source>
        <translation>Ausrichtung</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="171"/>
        <source>most</source>
        <translation>Meiste</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="179"/>
        <source>custom</source>
        <translation>Benutzer</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="238"/>
        <source>Open file</source>
        <translation>Datei öffnen</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="245"/>
        <source>History</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="249"/>
        <source>Info</source>
        <translation>Informationen</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="253"/>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="260"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="459"/>
        <source>Rotation</source>
        <translation>Ausrichtung</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="479"/>
        <source>No pages loaded</source>
        <translation>keine Seite(n) geladen</translation>
    </message>
</context>
<context>
    <name>OptionsPage</name>
    <message>
        <location filename="../OptionsPage.qml" line="25"/>
        <source>Page view</source>
        <translation>Seitenansicht</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="28"/>
        <source>Rotation</source>
        <translation>Ausrichtung</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="43"/>
        <source>auto</source>
        <translation>automatisch</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="51"/>
        <source>portrait</source>
        <translation>Hochformat</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="59"/>
        <source>landscape</source>
        <translation>Querformat</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="67"/>
        <source>Show status bar</source>
        <translation>Statusleiste anzeigen</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="75"/>
        <source>Remember toolbar state</source>
        <translation>Zustand der Werkzeugleiste merken</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="82"/>
        <source>Fullscreen button opacity</source>
        <translation>Sichtbarkeit des Vollbildumschalters</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="108"/>
        <source>Paging options</source>
        <translation>Blättern</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="111"/>
        <source>Paging mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="126"/>
        <source>Whole screen</source>
        <translation>ganzer Bildschirm</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="134"/>
        <source>On edges</source>
        <translation>an den Kanten</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="142"/>
        <source>Show paging feedback</source>
        <translation>Zeige Rückmeldung bei Blättern</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="152"/>
        <source>Page scaling</source>
        <translation>Seitenskalierung</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="155"/>
        <source>Page fit mode</source>
        <translation>Seite anpassen</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="164"/>
        <source>Miscellaneous</source>
        <translation>Verschiedenes</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="167"/>
        <source>Manga reading mode</source>
        <translation>Manga Lesemodus</translation>
    </message>
</context>
<context>
    <name>PageFitSelector</name>
    <message>
        <location filename="../PageFitSelector.qml" line="10"/>
        <source>Page fit mode</source>
        <translation>Seitenskalierungsmodus</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="18"/>
        <source>&lt;b&gt;1:1&lt;/b&gt; - original size</source>
        <translation>&lt;b&gt;1:1&lt;/b&gt; - Originalgröße</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="19"/>
        <source>&lt;b&gt;fit to width&lt;/b&gt;</source>
        <translation>&lt;b&gt;an Breite anpassen&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="20"/>
        <source>&lt;b&gt;fit to height&lt;/b&gt;</source>
        <translation>&lt;b&gt;an Höhe anpassen&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="21"/>
        <source>&lt;b&gt;fit to screen&lt;/b&gt;</source>
        <translation>&lt;b&gt;an Bildschirm anpassen&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="22"/>
        <source>&lt;b&gt;custom&lt;/b&gt; - remember scale</source>
        <translation>&lt;b&gt;benutzerdefiniert&lt;/b&gt; - Skalierung merken</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="23"/>
        <source>&lt;b&gt;orientation&lt;/b&gt; specific</source>
        <translation>&lt;b&gt;ausrichtungsspezifisch&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="24"/>
        <source>&lt;b&gt;show the most&lt;/b&gt;</source>
        <translation>&lt;b&gt;das Meiste zeigen&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>PayPalButton</name>
    <message>
        <location filename="../PayPalButton.qml" line="24"/>
        <source>Opening &lt;b&gt;PayPal&lt;/b&gt; donation page, &lt;b&gt;thanks&lt;/b&gt;!</source>
        <translation>Die &lt;b&gt;PayPal&lt;/b&gt; Spendeseite wird geöffnet, &lt;b&gt;vielen dank&lt;/b&gt;!</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="83"/>
        <source>How to turn pages</source>
        <translation>Blättern der Seiten</translation>
    </message>
    <message>
        <location filename="../main.qml" line="84"/>
        <source>Tap the &lt;b&gt;right half&lt;/b&gt; of the screen to go to the &lt;b&gt;next page&lt;/b&gt;.</source>
        <translation>Die &lt;b&gt;linke&lt;/b&gt; Bildschirmhälfte antippen um zur nächsten Seite zu gelangen.</translation>
    </message>
    <message>
        <location filename="../main.qml" line="85"/>
        <source>Tap the &lt;b&gt;left half&lt;/b&gt; to go to the &lt;b&gt;previous page&lt;/b&gt;.</source>
        <translation>Die &lt;b&gt;rechte&lt;/b&gt; Bildschirmhälfte antippen um zur vorherigen Seite zu gelangen.</translation>
    </message>
    <message>
        <location filename="../main.qml" line="86"/>
        <source>Don&apos;t show again</source>
        <translation>Nicht mehr zeigen</translation>
    </message>
    <message>
        <location filename="../main.qml" line="87"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
</TS>

==> mieru_2.4.5.tar.gz: mieru-2.4.5/mieru/opt/mieru/gui/qml/i18n/qml_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>BitcoinButton</name>
    <message>
        <location filename="../BitcoinButton.qml" line="34"/>
        <source>Bitcoin address</source>
        <translation>Bitcoin Adresse</translation>
    </message>
    <message>
        <location filename="../BitcoinButton.qml" line="111"/>
        <source>Copy address</source>
        <translation>Adresse kopieren</translation>
    </message>
    <message>
        <location filename="../BitcoinButton.qml" line="116"/>
        <source>Bitcoin address copied to clipboard</source>
        <translation>Die Bitcoin Adresse wurde in Zwischenablage kopiert</translation>
    </message>
</context>
<context>
    <name>FileSelector</name>
    <message>
        <location filename="../FileSelector.qml" line="14"/>
        <source>File Selector</source>
        <translation>Datei auswählen</translation>
    </message>
</context>
<context>
    <name>FlattrButton</name>
    <message>
        <location filename="../FlattrButton.qml" line="25"/>
        <source>Opening &lt;b&gt;Flattr&lt;/b&gt; donation page, &lt;b&gt;thanks&lt;/b&gt;!</source>
        <translation>Die &lt;b&gt;Flattr&lt;/b&gt; Spendeseite wird geöffnet, &lt;b&gt;vielen dank&lt;/b&gt;!</translation>
    </message>
</context>
<context>
    <name>HistoryPage</name>
    <message>
        <location filename="../HistoryPage.qml" line="20"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="31"/>
        <location filename="../HistoryPage.qml" line="118"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="54"/>
        <source>Do not delete items</source>
        <translation>keine Einträge löschen</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="54"/>
        <source>Delete items</source>
        <translation>Einträge löschen</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="57"/>
        <source>Select items to delete</source>
        <translation>Einträge zum Löschen auswählen</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="61"/>
        <location filename="../HistoryPage.qml" line="115"/>
        <source>Erase history</source>
        <translation>Verlauf löschen</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="74"/>
        <source>no entries</source>
        <translation>keine Einträge</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="116"/>
        <source>Do you want to erase the history of all mangas and comic books opened by Mieru?</source>
        <translation>Möchten Sie wirklich den gesamten Verlauf löschen?</translation>
    </message>
    <message>
        <location filename="../HistoryPage.qml" line="117"/>
        <source>Erase</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>InfoPage</name>
    <message>
        <location filename="../InfoPage.qml" line="14"/>
        <source>Info</source>
        <translation>Informationen</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="18"/>
        <source>Stats</source>
        <translation>Statistik</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="22"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="77"/>
        <source>Properties</source>
        <translation>Eigenschaften</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="80"/>
        <source>Pages</source>
        <translation>Seiten</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="83"/>
        <source>Path</source>
        <translation>Pfad</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="91"/>
        <source>Online search</source>
        <translation>Online Suche</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="97"/>
        <source>Opening &lt;b&gt;Google&lt;/b&gt; search</source>
        <translation>Öffne &lt;b&gt;Google&lt;/b&gt; Suche</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="106"/>
        <source>Opening &lt;b&gt;Wikipedia&lt;/b&gt; search</source>
        <translation>Öffne &lt;b&gt;Wikipedia&lt;/b&gt; Suche</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="115"/>
        <source>Opening &lt;b&gt;Manga updates&lt;/b&gt; search</source>
        <translation>Öffne &lt;b&gt;Manga Updates&lt;/b&gt; Suche</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="132"/>
        <source>Usage Statistics</source>
        <translation>Nutzungsstatistiken</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="162"/>
        <location filename="../InfoPage.qml" line="271"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="207"/>
        <source>Mieru is a flexible Manga and comic book reader.</source>
        <translation>Mieru ist ein flexibles Manga und Comic Anzeigeprogramm.</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="243"/>
        <source>main developer</source>
        <translation>Entwickler</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="246"/>
        <source>email</source>
        <translation>E-Mail</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="250"/>
        <source>www</source>
        <translation>Web</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="255"/>
        <source>discussion</source>
        <translation>Diskussion</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="269"/>
        <source>Reset all usage statistics</source>
        <translation>Nutzungsstatistiken zurücksetzen</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="270"/>
        <source>Do you really want to reset all usage statistics?</source>
        <translation>Möchten Sie wirklich alle Nutzungsstatistiken rücksetzen?</translation>
    </message>
    <message>
        <location filename="../InfoPage.qml" line="272"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../MainView.qml" line="156"/>
        <source>original</source>
        <translation>Original</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="158"/>
        <source>width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="160"/>
        <source>height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="162"/>
        <source>screen</source>
        <translation>Bildschirm</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="164"/>
        <source>orient</source>
        <translation>Ausrichtung</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="171"/>
        <source>most</source>
        <translation>Meiste</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="179"/>
        <source>custom</source>
        <translation>Benutzer</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="238"/>
        <source>Open file</source>
        <translation>Datei öffnen</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="245"/>
        <source>History</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="249"/>
        <source>Info</source>
        <translation>Informationen</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="253"/>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="260"/>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="459"/>
        <source>Rotation</source>
        <translation>Ausrichtung</translation>
    </message>
    <message>
        <location filename="../MainView.qml" line="479"/>
        <source>No pages loaded</source>
        <translation>Keine Seite(n) geladen</translation>
    </message>
</context>
<context>
    <name>OptionsPage</name>
    <message>
        <location filename="../OptionsPage.qml" line="27"/>
        <source>Page view</source>
        <translation>Seitenansicht</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="30"/>
        <source>Rotation</source>
        <translation>Ausrichtung</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="45"/>
        <source>auto</source>
        <translation>automatisch</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="53"/>
        <source>portrait</source>
        <translation>Hochformat</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="61"/>
        <source>landscape</source>
        <translation>Querformat</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="69"/>
        <source>Show status bar</source>
        <translation>Statusleiste anzeigen</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="77"/>
        <source>Remember toolbar state</source>
        <translation>Zustand der Werkzeugleiste merken</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="84"/>
        <source>Fullscreen button opacity</source>
        <translation>Sichtbarkeit des Vollbildumschalters</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="110"/>
        <source>Paging options</source>
        <translation>Blättern</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="113"/>
        <source>Paging mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="128"/>
        <source>Whole screen</source>
        <translation>ganzer Bildschirm</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="136"/>
        <source>On edges</source>
        <translation>an den Kanten</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="144"/>
        <source>Show paging feedback</source>
        <translation>Zeige Rückmeldung bei Blättern</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="154"/>
        <source>Page scaling</source>
        <translation>Seitenskalierung</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="157"/>
        <source>Page fit mode</source>
        <translation>Seite anpassen</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="166"/>
        <source>Miscellaneous</source>
        <translation>Verschiedenes</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="169"/>
        <source>Manga reading mode</source>
        <translation>Manga Lesemodus</translation>
    </message>
    <message>
        <location filename="../OptionsPage.qml" line="177"/>
        <source>Show release notes</source>
        <translation>&lt;i&gt;Release Notes&lt;/i&gt; zeigen</translation>
    </message>
</context>
<context>
    <name>PageFitSelector</name>
    <message>
        <location filename="../PageFitSelector.qml" line="10"/>
        <source>Page fit mode</source>
        <translation>Seitenskalierungsmodus</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="18"/>
        <source>&lt;b&gt;1:1&lt;/b&gt; - original size</source>
        <translation>&lt;b&gt;1:1&lt;/b&gt; - Originalgröße</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="19"/>
        <source>&lt;b&gt;fit to width&lt;/b&gt;</source>
        <translation>&lt;b&gt;an Breite anpassen&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="20"/>
        <source>&lt;b&gt;fit to height&lt;/b&gt;</source>
        <translation>&lt;b&gt;an Höhe anpassen&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="21"/>
        <source>&lt;b&gt;fit to screen&lt;/b&gt;</source>
        <translation>&lt;b&gt;an Bildschirm anpassen&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="22"/>
        <source>&lt;b&gt;custom&lt;/b&gt; - remember scale</source>
        <translation>&lt;b&gt;benutzerdefiniert&lt;/b&gt; - Skalierung merken</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="23"/>
        <source>&lt;b&gt;orientation&lt;/b&gt; specific</source>
        <translation>&lt;b&gt;ausrichtungsspezifisch&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../PageFitSelector.qml" line="24"/>
        <source>&lt;b&gt;show the most&lt;/b&gt;</source>
        <translation>&lt;b&gt;das Meiste zeigen&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>PayPalButton</name>
    <message>
        <location filename="../PayPalButton.qml" line="24"/>
        <source>Opening &lt;b&gt;PayPal&lt;/b&gt; donation page, &lt;b&gt;thanks&lt;/b&gt;!</source>
        <translation>Die &lt;b&gt;PayPal&lt;/b&gt; Spendeseite wird geöffnet, &lt;b&gt;vielen dank&lt;/b&gt;!</translation>
    </message>
</context>
<context>
    <name>WhatsNewDialog</name>
    <message>
        <location filename="../WhatsNewDialog.qml" line="35"/>
        <source>Opening link</source>
        <translation>Link wird geöffnet</translation>
    </message>
    <message>
        <location filename="../WhatsNewDialog.qml" line="48"/>
        <source>&lt;b&gt;Do you like Mieru ? Donate !&lt;/b&gt;</source>
        <translation>&lt;b&gt;Mögen Sie Mieru ? Spenden willkommen !&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../WhatsNewDialog.qml" line="56"/>
        <source>How to donate ?</source>
        <translation>Wie kann man spenden ?</translation>
    </message>
    <message>
        <location filename="../WhatsNewDialog.qml" line="67"/>
        <source>Don&apos;t show again</source>
        <translation>Nicht mehr zeigen</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="85"/>
        <source>How to turn pages</source>
        <translation>Blättern der Seiten</translation>
    </message>
    <message>
        <location filename="../main.qml" line="86"/>
        <source>Tap the &lt;b&gt;right half&lt;/b&gt; of the screen to go to the &lt;b&gt;next page&lt;/b&gt;.</source>
        <translation>Die &lt;b&gt;linke&lt;/b&gt; Bildschirmhälfte antippen um zur nächsten Seite zu gelangen.</translation>
    </message>
    <message>
        <location filename="../main.qml" line="87"/>
        <source>Tap the &lt;b&gt;left half&lt;/b&gt; to go to the &lt;b&gt;previous page&lt;/b&gt;.</source>
        <translation>Die &lt;b&gt;rechte&lt;/b&gt; Bildschirmhälfte antippen um zur vorherigen Seite zu gelangen.</translation>
    </message>
    <message>
        <location filename="../main.qml" line="88"/>
        <source>Don&apos;t show again</source>
        <translation>Nicht mehr zeigen</translation>
    </message>
    <message>
        <location filename="../main.qml" line="89"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
</TS>
